=====
audyo
=====

Python audio manager

Description
===========

Simple i/o package for "audio things". You can easily record a phrase or play audio files.


Note
====

Microphone object can record until silence is detected.
This package provide two terminal commands:

- audyo-rec: This command will record until silence to default "audyo.wav" file. (output parameter will be released soon)
- audyo-play: This command will play audio file passed by parameter (will be released soon)
